# Data Dictionary

---

*We are currently updating the nomenclature of many of the data in `pgfinder`. For now, use this page with caution.*

---

Effective use of `pgfinder` requires an understanding of the inputs and outputs of the software.

## Inputs

`pgfinder` takes data from mass spectrometry instruments, as well as a "database" of expected
masses and some user specified modifications.

### FTRS Files

This is a file corresponding to deconvolution data generated by the [Byos®](https://proteinmetrics.com/byos/)
 software with the extension `.ftrs`.

### MaxQuant Files

MaxQuant Files are output by the [MaxQuant](https://www.maxquant.org/) software. They are
tab separated value (`TSV`) files with a `.txt` extension.

### Modifications

Any number of modifications can be selected to enrich the search space of the database of masses
to which the input data is being compared. Allowed mofifications are:

| Modification | Description |
|---|---|
| Sodium	| Search for masses corresponding to sodium adducts |
| Potassium	| Search for masses corresponding to potassium adducts |
| Anh	| Search for anhydromuropeptides |
| DeAc	| Search for deacetylated muropeptides |
| DeAc_Anh	| Search for deacetylated anhydromuropeptides |
| Nude	| Search for muropeptides with an extra GlcNAc-MurNAc disaccharide |
| Decay	| Correct output taking into account in-source decay products |
| Amidation | Search for Amidated muropeptides |
| Amidase	| Search for peptides resulting from amidase cleavage (GlcNAc-MurNAc loss) |
| Double_Anh	| Search for anhydromuropeptides (2 Anhydro groups) |
| Multimers	| Search for multimers resulting from 3-3 and 4-3 crosslinks |
| Multimers | Glyco	Search for multimers resulting from transglycosylation (no transpeptidation |
| Multimer Lac	| Search for lactyl-peptides multimers |
| O-Ac	| Search for O-acetylated muropeptides |

### Mass Databases (Lists)

Mass databases are lists of structures and their associated mass. They are in `CSV` format
with a `.csv` extension. `pgfinder` has built-in mass lists for *Escherichia coli* and
*Clostridium difficle*, but can take a different mass list as an input.

| Column           | Description       | Unit             |
|------------------|-------------------|------------------|
| Structure        | Structure code    | NA               |
| Monoisotopicmass | Monoisotopic mass | atomic mass unit |

## Outputs

`pgfinder` outputs `CSV` (`.csv`) files. The columns in these files depend on the input file format.

### FTRS Output Files

The column name of the first column contains [embedded metadata](#embedded-metadata) on the provenance of the file. Subsequent columns are defined as follows:

| Column              | Description                                                                    | Unit |
|---------------------|--------------------------------------------------------------------------------|------|
| ID                  | Feature identified from ions corresponding to the same mass and retention time | NA   |
| xicStart            | Extracted ion chromatogram starting time point                                 | min  |
| xicEnd              | Extracted ion chromatogram starting time point                                 | min  |
| ionCount            | Number of occurrence for ions corresponding to the same feature                | NA   |
| chargeOrder         | Observed ion charge states                                                     | NA   |
| rt                  | Retention time                                                                 | min  |
| mwMonoisotopic      | Observed monoisotopic mass                                                     | Da   |
| theo_mwMonoisotopic | Theoretical monoisotopic mass                                                  | Da   |
| inferredStructure   | Inferred muropeptide structure                                                 | NA   |
| maxIntensity        | Signal intensity calculated from Extracted Ion Chromatograms                   | NA   |

### MaxQuant Output Files

The column name of the first column contains [embedded metadata](#embedded-metadata) on the provenance of the file. Subsequent columns are defined as follows:

| Column | Description | Unit |
|---|---|---|
| ID | Feature identified from ions corresponding to the same mass and retention time | NA |
| rt | Retention time | min |
| rt_length | Time window used to quantify signal intensity based on Extracted Ion Chromatograms | min |
| mwMonoisotopic | Observed monoisotopic mass | Da |
| theo_mwMonoisotopic | Theoretical monoisotopic mass | Da |
| inferredStructure | Inferred muropeptide structure | NA |
| maxIntensity | Signal intensity calculated from Extracted Ion Chromatograms  | NA |

### Embedded Metadata

| Data | Description |
|---|---|
| file | Input data file |
| masses_file | Mass list file |
| modifications | List of [modifications](#modifications) |
| ppm | ppm tolerance |
| rt_window | Window used for in-source decay correction (min) |
